.. :changelog:

History
-------

0.1.1 (2018-05-21)
++++++++++++++++++

* First release on PyPI.

1.0.0 (2018-07-03)
++++++++++++++++++

* First production release.

1.1 2018-07-28
++++++++++++++++
* Now supports DjangoModelPermissions as a global authentication setting
  across all views and viewsets.
* New convenience management command to support the creation of default groups.
* Fixed management command error (patch 1)
* Fixed wrong pattern identifier in NDC pattern choices
* Fixed unique NDC issue in TradeItem model.

1.8
+++

*   Added 11-digit NDC conversion to the Trade Item model.
